@@ -24,6 +24,7 @@ class MatrixThree(object):
         self.npy[2,0] = vals[6]
         self.npy[2,1] = vals[7]
         self.npy[2,2] = vals[8]
+        self.npy = self.npy.transpose()
 
         
     def get_inverse(self):
@@ -70,7 +71,7 @@ class MatrixThree(object):
         if self.newver:
             #################################
             from numpy.linalg import det
-            return det(self.npy.transpose())
+            return det(self.npy)
             #################################
         else:
             factor = -1
@@ -78,7 +79,7 @@ class MatrixThree(object):
             for i in range(3):        
                 factor = factor * -1
                 row_val = self.matrix[3 * i]
-                newdet = self.get_inner_determinant(i, 0)
+                newdet = self.get_inner_determinant(0, i)
                 det = det + (factor * row_val * newdet)
             return det
     
